@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <gsl/gsl_math.h>
@@ -212,7 +213,7 @@ main (void)
   test_complex_float_trap ();
   test_complex_long_double_trap ();
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 void
